> This python package will have a collection of structures, functions and tools for interacting with LLMs and Datasets.

## Project and PyPI Package 
- https://pypi.org/project/slowblood/
- https://github.com/kyledinh/slowblood
- https://huggingface.co/Slowblood

## Usage Examples

- TODO 